==> mediawiki-1.30.0-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/SpamBlacklist/tests/phpunit/BaseBlacklistTest.php <==
<?php

/**
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @file
 */

/**
 * @covers BaseBlacklist
 */
class BaseBlacklistTest extends MediaWikiTestCase {

	/**
	 * @return array
	 */
	public static function provideGetTypeFromTitle() {
		return [
			[ 'MediaWiki:Spam-blacklist', 'spam' ],
			[ 'MediaWiki:Spam-whitelist', 'spam' ],
			[ 'MediaWiki:Email-whitelist', 'email' ],
			[ 'MediaWiki:Email-blacklist', 'email' ],
			[ 'MediaWiki:A random page', false ],
			[ 'Another random page', false ],
		];
	}

	/**
	 * @dataProvider provideGetTypeFromTitle
	 * @param string $title
	 * @param string|bool $expected
	 */
	public function testGetTypeFromTitle( $title, $expected ) {
		$title = Title::newFromText( $title );
		$output = BaseBlacklist::getTypeFromTitle( $title );
		$this->assertEquals( $expected, $output );
	}
}

==> mediawiki-1.38.4-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/SpamBlacklist/tests/phpunit/BaseBlacklistTest.php <==
<?php

/**
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @file
 */

/**
 * @covers BaseBlacklist
 */
class BaseBlacklistTest extends MediaWikiIntegrationTestCase {

	/**
	 * @return array
	 */
	public static function provideGetTypeFromTitle() {
		return [
			[ 'MediaWiki:Spam-blacklist', 'spam' ],
			[ 'MediaWiki:Spam-whitelist', 'spam' ],
			[ 'MediaWiki:Email-whitelist', 'email' ],
			[ 'MediaWiki:Email-blacklist', 'email' ],
			[ 'MediaWiki:A random page', false ],
			[ 'Another random page', false ],
		];
	}

	/**
	 * @dataProvider provideGetTypeFromTitle
	 * @param string $title
	 * @param string|bool $expected
	 */
	public function testGetTypeFromTitle( $title, $expected ) {
		$title = Title::newFromText( $title );
		$output = BaseBlacklist::getTypeFromTitle( $title );
		$this->assertEquals( $expected, $output );
	}
}
